@@ -30,8 +30,7 @@ from typing import (
 
 from robotcode.core.async_tools import Lock, async_event
 from robotcode.core.logging import LoggingDescriptor
-from robotcode.core.uri import Uri
-from robotcode.language_server.common.lsp_types import (
+from robotcode.core.lsp.types import (
     CodeDescription,
     Diagnostic,
     DiagnosticRelatedInformation,
@@ -42,6 +41,7 @@ from robotcode.language_server.common.lsp_types import (
     Position,
     Range,
 )
+from robotcode.core.uri import Uri
 from robotcode.language_server.common.text_document import TextDocument
 from robotcode.language_server.robotframework.languages import Languages
 from robotcode.language_server.robotframework.utils.ast_utils import (
@@ -419,28 +419,28 @@ class ImportVisitor(Visitor):
         last_data_token = cast(
             RobotToken, next(v for v in reversed(n.tokens) if v.type not in RobotToken.NON_DATA_TOKENS)
         )
-
-        self._results.append(
-            LibraryImport(
-                name=n.name,
-                name_token=name if name is not None else None,
-                args=n.args,
-                alias=n.alias,
-                line_no=node.lineno,
-                col_offset=node.col_offset,
-                end_line_no=last_data_token.lineno
-                if last_data_token is not None
-                else node.end_lineno
-                if node.end_lineno is not None
-                else -1,
-                end_col_offset=last_data_token.end_col_offset
-                if last_data_token is not None
-                else node.end_col_offset
-                if node.end_col_offset is not None
-                else -1,
-                source=self.source,
+        if n.name:
+            self._results.append(
+                LibraryImport(
+                    name=n.name,
+                    name_token=name if name is not None else None,
+                    args=n.args,
+                    alias=n.alias,
+                    line_no=node.lineno,
+                    col_offset=node.col_offset,
+                    end_line_no=last_data_token.lineno
+                    if last_data_token is not None
+                    else node.end_lineno
+                    if node.end_lineno is not None
+                    else -1,
+                    end_col_offset=last_data_token.end_col_offset
+                    if last_data_token is not None
+                    else node.end_col_offset
+                    if node.end_col_offset is not None
+                    else -1,
+                    source=self.source,
+                )
             )
-        )
 
     def visit_ResourceImport(self, node: ast.AST) -> None:  # noqa: N802
         from robot.parsing.lexer.tokens import Token as RobotToken
@@ -452,25 +452,26 @@ class ImportVisitor(Visitor):
         last_data_token = cast(
             RobotToken, next(v for v in reversed(n.tokens) if v.type not in RobotToken.NON_DATA_TOKENS)
         )
-        self._results.append(
-            ResourceImport(
-                name=n.name,
-                name_token=name if name is not None else None,
-                line_no=node.lineno,
-                col_offset=node.col_offset,
-                end_line_no=last_data_token.lineno
-                if last_data_token is not None
-                else node.end_lineno
-                if node.end_lineno is not None
-                else -1,
-                end_col_offset=last_data_token.end_col_offset
-                if last_data_token is not None
-                else node.end_col_offset
-                if node.end_col_offset is not None
-                else -1,
-                source=self.source,
+        if n.name:
+            self._results.append(
+                ResourceImport(
+                    name=n.name,
+                    name_token=name if name is not None else None,
+                    line_no=node.lineno,
+                    col_offset=node.col_offset,
+                    end_line_no=last_data_token.lineno
+                    if last_data_token is not None
+                    else node.end_lineno
+                    if node.end_lineno is not None
+                    else -1,
+                    end_col_offset=last_data_token.end_col_offset
+                    if last_data_token is not None
+                    else node.end_col_offset
+                    if node.end_col_offset is not None
+                    else -1,
+                    source=self.source,
+                )
             )
-        )
 
     def visit_VariablesImport(self, node: ast.AST) -> None:  # noqa: N802
         from robot.parsing.lexer.tokens import Token as RobotToken
@@ -482,26 +483,27 @@ class ImportVisitor(Visitor):
         last_data_token = cast(
             RobotToken, next(v for v in reversed(n.tokens) if v.type not in RobotToken.NON_DATA_TOKENS)
         )
-        self._results.append(
-            VariablesImport(
-                name=n.name,
-                name_token=name if name is not None else None,
-                args=n.args,
-                line_no=node.lineno,
-                col_offset=node.col_offset,
-                end_line_no=last_data_token.lineno
-                if last_data_token is not None
-                else node.end_lineno
-                if node.end_lineno is not None
-                else -1,
-                end_col_offset=last_data_token.end_col_offset
-                if last_data_token is not None
-                else node.end_col_offset
-                if node.end_col_offset is not None
-                else -1,
-                source=self.source,
+        if n.name:
+            self._results.append(
+                VariablesImport(
+                    name=n.name,
+                    name_token=name if name is not None else None,
+                    args=n.args,
+                    line_no=node.lineno,
+                    col_offset=node.col_offset,
+                    end_line_no=last_data_token.lineno
+                    if last_data_token is not None
+                    else node.end_lineno
+                    if node.end_lineno is not None
+                    else -1,
+                    end_col_offset=last_data_token.end_col_offset
+                    if last_data_token is not None
+                    else node.end_col_offset
+                    if node.end_col_offset is not None
+                    else -1,
+                    source=self.source,
+                )
             )
-        )
 
 
 @dataclass
@@ -517,7 +519,7 @@ class LibraryEntry:
     def __str__(self) -> str:
         result = self.import_name
         if self.args:
-            result += f"  {str(self.args)}"
+            result += f"  {self.args!s}"
         if self.alias:
             result += f"  WITH NAME  {self.alias}"
         return result
@@ -1726,7 +1728,7 @@ class KeywordFinder:
                 if result is None:
                     self.diagnostics.append(
                         DiagnosticsEntry(
-                            f"No keyword with name {repr(name)} found.",
+                            f"No keyword with name '{name}' found.",
                             DiagnosticSeverity.ERROR,
                             "KeywordNotFoundError",
                         )
@@ -1769,7 +1771,7 @@ class KeywordFinder:
         return result
 
     def _get_keyword_from_self(self, name: str) -> Optional[KeywordDoc]:
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             found: List[Tuple[Optional[LibraryEntry], KeywordDoc]] = [
                 (None, v) for v in self.self_library_doc.keywords.get_all(name)
             ]
@@ -1813,7 +1815,7 @@ class KeywordFinder:
         for owner_name, kw_name in self._yield_owner_and_kw_names(name):
             found.extend(self.find_keywords(owner_name, kw_name))
 
-        if get_robot_version() >= (6, 0, 0) and len(found) > 1:
+        if get_robot_version() >= (6, 0) and len(found) > 1:
             found = self._select_best_matches(found)
 
         if len(found) > 1:
@@ -1832,7 +1834,7 @@ class KeywordFinder:
         if self._all_keywords is None:
             self._all_keywords = list(chain(self.namespace._libraries.values(), self.namespace._resources.values()))
 
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             result: List[Tuple[LibraryEntry, KeywordDoc]] = []
             for v in self._all_keywords:
                 if eq(v.alias or v.name, owner_name):
@@ -1914,7 +1916,7 @@ class KeywordFinder:
         if self._resource_keywords is None:
             self._resource_keywords = list(chain(self.namespace._resources.values()))
 
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             found: List[Tuple[Optional[LibraryEntry], KeywordDoc]] = []
             for v in self._resource_keywords:
                 r = v.library_doc.keywords.get_all(name)
@@ -1930,7 +1932,7 @@ class KeywordFinder:
         if not found:
             return None
 
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             if len(found) > 1:
                 found = self._prioritize_same_file_or_public(found)
 
@@ -1970,7 +1972,7 @@ class KeywordFinder:
         if self._library_keywords is None:
             self._library_keywords = list(chain(self.namespace._libraries.values()))
 
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             found: List[Tuple[Optional[LibraryEntry], KeywordDoc]] = []
             for v in self._library_keywords:
                 r = v.library_doc.keywords.get_all(name)
@@ -1987,7 +1989,7 @@ class KeywordFinder:
         if not found:
             return None
 
-        if get_robot_version() >= (6, 0, 0):
+        if get_robot_version() >= (6, 0):
             if len(found) > 1:
                 found = self._select_best_matches(found)
                 if len(found) > 1:
