@@ -123,6 +123,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
                     except (asyncio.CancelledError, SystemExit, KeyboardInterrupt):
                         raise
                     except BaseException:
+                        self._logger.exception("Error resolving variable: {e}")
                         value = ""
                 else:
                     value = ""
@@ -398,7 +399,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
 
         library_node = cast(LibraryImport, node)
         if library_node.name:
-            name_token = cast(RobotToken, library_node.get_token(RobotToken.NAME))
+            name_token = library_node.get_token(RobotToken.NAME)
             if name_token is None:
                 return None
 
@@ -547,7 +548,7 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         self, node: ast.AST, nodes: List[ast.AST], document: TextDocument, position: Position
     ) -> Optional[Hover]:
         from robot.parsing.lexer.tokens import Token as RobotToken
-        from robot.parsing.model.blocks import TestCase
+        from robot.parsing.model.blocks import TestCase, TestCaseSection
         from robot.parsing.model.statements import Documentation, Tags
 
         test_case = cast(TestCase, node)
@@ -562,7 +563,11 @@ class RobotHoverProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         doc = next((e for e in test_case.body if isinstance(e, Documentation)), None)
         tags = next((e for e in test_case.body if isinstance(e, Tags)), None)
 
-        txt = f"= Test Case *{test_case.name}* =\n"
+        section = next((e for e in nodes if isinstance(e, TestCaseSection)), None)
+        if section is not None and section.tasks:
+            txt = f"= Task *{test_case.name}* =\n"
+        else:
+            txt = f"= Test Case *{test_case.name}* =\n"
 
         if doc is not None:
             txt += "\n== Documentation ==\n"
